@@ -24,7 +24,16 @@ class MerchantAccount(Resource):
             self.master_merchant_account = MerchantAccount(gateway, attributes.pop("master_merchant_account"))
 
     def __repr__(self):
-        detail_list = ["id", "status", "master_merchant_account", "individual_details", "business_details", "funding_details", "default"]
+        detail_list = [
+            "id",
+            "business_details",
+            "currency_iso_code",
+            "default",
+            "funding_details",
+            "individual_details",
+            "master_merchant_account",
+            "status",
+        ]
         return super(MerchantAccount, self).__repr__(detail_list)
 
     @staticmethod
