@@ -553,12 +553,14 @@ class Transaction(Resource):
                     "store_shipping_address_in_vault",
                     "submit_for_settlement",
                     "venmo_sdk_session",
+                    "payee_id",
                     "payee_email",
                     "skip_advanced_fraud_checking",
                     "skip_avs",
                     "skip_cvv",
                     {
                         "paypal": [
+                            "payee_id",
                             "payee_email",
                             "custom_field",
                             "description",
@@ -579,6 +581,9 @@ class Transaction(Resource):
                             "originating_merchant_id",
                             "originating_merchant_kind"
                         ],
+                        "venmo": [
+                            "profile_id"
+                        ],
                     },
                     {
                         "adyen": [
@@ -590,7 +595,7 @@ class Transaction(Resource):
             },
             {"custom_fields": ["__any_key__"]},
             {"descriptor": ["name", "phone", "url"]},
-            {"paypal_account": ["payee_email"]},
+            {"paypal_account": ["payee_id", "payee_email"]},
             {"industry":
                 [
                     "industry_type",
@@ -603,7 +608,7 @@ class Transaction(Resource):
                 },
             {"line_items":
                 [
-                    "quantity", "name", "description", "kind", "unit_amount", "unit_tax_amount", "total_amount", "discount_amount", "unit_of_measure", "product_code", "commodity_code", "url",
+                    "quantity", "name", "description", "kind", "unit_amount", "unit_tax_amount", "total_amount", "discount_amount", "tax_amount", "unit_of_measure", "product_code", "commodity_code", "url",
                 ]
             },
         ]
